aboutsummaryrefslogtreecommitdiffstats
path: root/phpBB/phpbb/auth/auth.php
diff options
context:
space:
mode:
authorn-aleha <nick_aleha@myway.com>2014-05-24 16:55:52 +0300
committern-aleha <nick_aleha@myway.com>2014-08-03 07:13:20 +0300
commit95ec9590dfd2e93a75383745f385aaa3493ed857 (patch)
treef10ec7c16d0cbf9411f1e07d8fc076eebbdd8bc6 /phpBB/phpbb/auth/auth.php
parent6ac8d17af66900c87b4524c92e0cc26535ded7b0 (diff)
downloadforums-95ec9590dfd2e93a75383745f385aaa3493ed857.tar
forums-95ec9590dfd2e93a75383745f385aaa3493ed857.tar.gz
forums-95ec9590dfd2e93a75383745f385aaa3493ed857.tar.bz2
forums-95ec9590dfd2e93a75383745f385aaa3493ed857.tar.xz
forums-95ec9590dfd2e93a75383745f385aaa3493ed857.zip
[ticket/12557] Fix doc block errors found by Sami
PHPBB3-12557
Diffstat (limited to 'phpBB/phpbb/auth/auth.php')
-rw-r--r--phpBB/phpbb/auth/auth.php5
1 files changed, 3 insertions, 2 deletions
diff --git a/phpBB/phpbb/auth/auth.php b/phpBB/phpbb/auth/auth.php
index ecc981eb9f..38755ccf99 100644
--- a/phpBB/phpbb/auth/auth.php
+++ b/phpBB/phpbb/auth/auth.php
@@ -209,10 +209,11 @@ class auth
/**
* Get forums with the specified permission setting
*
- * @param string $opt The permission name to lookup. If it's prefixed with !, then the result becomes negated.
+ * @param string $opt The permission name to lookup. If prefixed with !, the result is negated.
* @param bool $clean set to true if only values needs to be returned which are set/unset
*
- * @return array Contains the forum ids with the specified permision set to true.
+ * @return array Contains the forum ids with the specified permission set to true.
+ This is a nested array: array => forum_id => permission => true
*/
function acl_getf($opt, $clean = false)
{